==> evilscan-1.7.3.tgz: package/test/J.scan.ports.banner.js <==
const expect = require('chai').expect;
const net = require('net')
const telnet = require('sol-telnet'); // the only one supporting IAC server side
const path = require('path');
const evilscan = require('../');
const port = 1026;

// Local fake server
const server = function(options,cb) {
    let s = net.createServer(function(sock){
        let ts = new telnet();
        sock.pipe(ts).pipe(sock);

    }).on('connection',function(s) {
        setTimeout(function() {
            return s.write(options.banner);
        },options.timeout||0);
    }).listen(port,cb)
    return s;
}

suite(path.basename(__filename), a => {

    let socketTimeout = 100;
    let testTimeout = 300;

    let opts = {
        target:'127.0.0.1',
        port:port,
        timeout:socketTimeout,
        banner:true
    };

    let TcpScan = require('../libs/TcpScan');

    let commonCheck = (r) => {
        expect(r).to.be.a('object');
        expect(r).to.have.property('status');
    }

    test('connection should be refused 127.0.0.1:'+port, function(next) {

        this.timeout(testTimeout);

        new evilscan(opts)
            .on('error', err => {throw new Error(data.toString())})
            .on('result', r => {
                commonCheck(r);
                expect(r.status).to.be.equal('close (refused)');
            })
            .on('done', () => {
                next();
            })
            .run();

    });


    test('connection should be ok 127.0.0.1:'+port, function(next) {

        this.timeout(testTimeout);

        let banner = 'hello\r\nworld\r\n';
        let srv = server({banner:banner}, err => {

            new evilscan(opts)
                .on('error', err => {throw new Error(data.toString())})
                .on('result', r => {
                    commonCheck(r);
                    expect(r.status).to.be.equal('open');
                    expect(r.banner).to.be.equal('hello\\r\\nworld\\r\\n');
                })
                .on('done', () => {
                    srv.close(next);
                })
                .run();
        });
    });

});

==> evilscan-1.7.9.tgz: package/test/J.scan.ports.banner.js <==
const expect = require('chai').expect;
const net = require('net');
const telnet = require('sol-telnet'); // the only one supporting IAC server side
const path = require('path');
const evilscan = require('../');
const port = 1026;

// Local fake server
const server = function(options, cb) {
    const s = net.createServer(sock => {
        const ts = new telnet();
        sock.pipe(ts).pipe(sock);
    }).on('connection', s => {
        setTimeout(() => {
            return s.write(options.banner);
        }, options.timeout||0);
    }).listen(port, cb);
    return s;
};

suite(path.basename(__filename), () => {

    const socketTimeout = 100;
    const testTimeout = 300;

    const opts = {
        target:'127.0.0.1',
        port,
        timeout:socketTimeout,
        banner:true
    };

    const commonCheck = (r) => {
        expect(r).to.be.a('object');
        expect(r).to.have.property('status');
    };

    test('connection should be refused 127.0.0.1:'+port, function(next) {

        this.timeout(testTimeout);

        new evilscan(opts)
            .on('error', err => {
                throw new Error(err);
            })
            .on('result', r => {
                commonCheck(r);
                expect(r.status).to.be.equal('close (refused)');
            })
            .on('done', () => {
                next();
            })
            .run();

    });


    test('connection should be ok 127.0.0.1:'+port, function(next) {

        this.timeout(testTimeout);

        const banner = 'hello\r\nworld\r\n';
        const srv = server({ banner }, (/*err*/) => {

            new evilscan(opts)
                .on('error', err => {
                    throw new Error(err);
                })
                .on('result', r => {
                    commonCheck(r);
                    expect(r.status).to.be.equal('open');
                    expect(r.banner).to.be.equal('hello\\r\\nworld\\r\\n');
                })
                .on('done', () => {
                    srv.close(next);
                })
                .run();
        });
    });

});
